@@ -27,24 +27,13 @@ mlmle <- function(data, ...) {
   # run optimization in unconstrained parameters
   log_l <- function(theta) {
     theta <- theta_orig(theta)
+    theta[1] <- min(theta[1], 1)
     - sum(dml(data, theta[1], theta[2], log = TRUE))
   }
   opt_out <- stats::optim(theta_init, fn = log_l, ...)
   alt_loglik  <- -opt_out$value
-  null_loglik <-
-    -stats::optimise(
-      f = function(rate)
-        - sum(stats::dexp(data, rate, log = TRUE)),
-      interval = c(0, 1000)
-    )$objective
-  p_value <-
-    stats::pchisq(2 * (alt_loglik - null_loglik),
-           df = 1,
-           lower.tail = FALSE)
   list(
     par = theta_orig(opt_out$par),
-    loglik = alt_loglik,
-    null_loglik = null_loglik,
-    p_value = p_value
+    loglik = alt_loglik
   )
 }
